@@ -1,7 +1,11 @@
+from __future__ import print_function
 import sys
 import json
 from operator import itemgetter
 import re
+from datetime import datetime
+from exceptions import FutureWarning
+from warnings import warn
 
 import requests
 from http_signature.requests_auth import HTTPSignatureAuth
@@ -22,10 +26,10 @@ KNOWN_LOCATIONS = {
 }
 
 TELEFONICA_LOCATIONS = {
-    u'London': u'https://eu-lon-1.api.instantservers.telefonica.com', 
-    u'eu-lon-1': u'https://eu-lon-1.api.instantservers.telefonica.com', 
-    u'Madrid': u'https://eu-mad-1.api.instantservers.telefonica.com',
-    u'eu-mad-1': u'https://eu-mad-1.api.instantservers.telefonica.com',
+    u'London': u'https://api-eu-lon-1.instantservers.telefonica.com', 
+    u'eu-lon-1': u'https://api-eu-lon-1.instantservers.telefonica.com', 
+    u'Madrid': u'https://api-eu-mad-1.instantservers.telefonica.com',
+    u'eu-mad-1': u'https://api-eu-mad-1.instantservers.telefonica.com',
 }
 
 DEFAULT_LOCATION = 'us-west-1'
@@ -61,7 +65,7 @@ class DataCenter(object):
     """
     def __init__(self, location=None, key_id=None, secret='~/.ssh/id_rsa', 
                 headers=None, login=None, config=None, known_locations=None,
-                allow_agent=False, verify=True):
+                allow_agent=False, verify=True, verbose=None):
         """
         A :py:class:`smartdc.datacenter.DataCenter` object may be instantiated 
         without any parameters, but practically speaking, the `key_id` and 
@@ -83,7 +87,7 @@ class DataCenter(object):
         :param login: user path in SmartDC
         :type login: :py:class:`basestring`
         
-        :param config: Requests-style configuration
+        :param config: Requests-style configuration [deprecated]
         :type config: :py:class:`dict`
         
         :param known_locations: keys-to-URLs mapping used by `location` 
@@ -95,6 +99,9 @@ class DataCenter(object):
         :param verify: whether or not to verify server SSL certificates
         :type verify: :py:class:`bool`
         
+        :param verbose: whether or not to print request URLs to stderr, overrides config
+        :type verbose: :py:class:`bool`
+        
         The `location` is notionally a hostname, but it may be 
         expressed as an FQDN, one of the keys to the `known_locations` dict, 
         or, as a fallback, a bare hostname as prefix to the API_HOST_SUFFIX.
@@ -113,7 +120,12 @@ class DataCenter(object):
         """
         self.location = location or DEFAULT_LOCATION
         self.known_locations = known_locations or KNOWN_LOCATIONS
-        self.config = config or {}
+        if verbose is None and config and config.get('verbose'):
+            self.verbose = config.get('verbose')
+            warn("DataCenter: config= will be eliminated in "
+                "favor of verbose=", FutureWarning, stacklevel=2)
+        else:
+            self.verbose = verbose and sys.stderr
         self.verify = verify
         if key_id and secret:
             self.auth = HTTPSignatureAuth(key_id=key_id, secret=secret,
@@ -227,8 +239,12 @@ class DataCenter(object):
         jdata = None
         if data:
             jdata = json.dumps(data)
+        if self.verbose:
+            print("%s\t%s\t%s" % 
+                (datetime.now().isoformat(), method, full_path), 
+                file=self.verbose)
         resp = requests.request(method, full_path, auth=self.auth, 
-            headers=request_headers, config=self.config, data=jdata,
+            headers=request_headers, data=jdata,
             verify=self.verify, **kwargs)
         if (resp.status_code == 401 and self.auth and 
                 self.auth.signer._agent_key):
@@ -237,7 +253,7 @@ class DataCenter(object):
                 **kwargs)
         if 400 <= resp.status_code < 499:
             if resp.content:
-                print >> sys.stderr, resp.content
+                print(resp.content, file=sys.stderr)
             resp.raise_for_status()
         if resp.content:
             if resp.headers['content-type'] == 'application/json':
@@ -257,6 +273,10 @@ class DataCenter(object):
             and URL templates
         :rtype: :py:class:`dict`
         """
+        if self.verbose:
+            print("%s\t%s\t%s" % 
+                (datetime.now().isoformat(), 'GET', self.base_url), 
+                file=self.verbose)
         resp = requests.request('GET', self.base_url, verify=self.verify)
         if 400 <= resp.status_code < 499:
             resp.raise_for_status()
@@ -370,7 +390,7 @@ class DataCenter(object):
         if name not in self.known_locations and '.' not in name:
             self.datacenters()
         dc = DataCenter(location=name, headers=self.default_headers, 
-                login=self.login, config=self.config, 
+                login=self.login, verbose=self.verbose, 
                 verify=self.verify, known_locations=self.known_locations)
         dc.auth = self.auth
         return dc
@@ -703,6 +723,7 @@ class DataCenter(object):
         """
         params = {}
         if name:
+            assert re.match(r'[a-zA-Z0-9]([a-zA-Z0-9\-\.]*[a-zA-Z0-9])?$', name), "Illegal name"
             params['name'] = name
         if package:
             if isinstance(package, dict):
@@ -723,7 +744,7 @@ class DataCenter(object):
                 params['metadata.user-script'] = f.read()
         j, r = self.request('POST', 'machines', data=params)
         if r.status_code >= 400:
-            print >> sys.stderr, j
+            print(j, file=sys.stderr)
             r.raise_for_status()
         return Machine(datacenter=self, data=j)
     
